#
# spec file for package topgrade
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           topgrade
Version:        12.0.2
Release:        bp156.1.7
Summary:        Upgrade all the things
License:        GPL-3.0-only
Group:          Productivity/Other
URL:            https://github.com/%{name}-rs/%{name}
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  zstd
ExclusiveArch:  %{rust_tier1_arches}

%description
Keeping your system up to date usually involves invoking multiple package managers. This results in big, non-portable shell one-liners saved in your shell.
To remedy this, Topgrade detects which tools you use and runs the appropriate commands to update them

%prep
%autosetup -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Sat Jul 29 2023 stigpro@outlook.fr 
- Update to version 12.0.2:
  * chore: release v12.0.2 (#518)
  * fix: WSL detection (#508)
  * fix: fix Linux and DragonFlyBSD yes option (#513)
  * feat: extra arguments for Home Manager (#507)
  * feat: better error message on wrong os-release file (#511)
  * chore: release v12.0.1 (#510)
  * chore: bump ci toolchain and MSRV (#506)
  * fix(oh-my-zsh): fix remote oh-my-zsh issue (#496)
  * CI: release to PyPI (#500)
  * feat: add assume-yes to more Linux managers (#501)
  * test: unit test for Solus (#504)
  * Fix clippy warning about non_minimal_cfg (#505)
  * Ass assume-yes to DragonflyBSD (#502)
  * steps/toolbx: Don't self-update and don't send notifications (#503)
  * chore: bump tempfile to ~3.6
  * fix(generic): add alternate binary name for spicetify (#486)
  * docs(config): document 4 missing sections in example config file (#485)
  * fix: fix wrong path in oh-my-bash (#478)
  * ci: separate code-coverage and test-config-creation (#488)
  * docs: apply corrections in config.example.toml (#492)
  * docs: add Karma commit messages to CONTRIBUTING.md (#493)
  * Update only base conda env (#495)
  * refactor(config): move sudo_command to section misc (#484)
  * v12 Cargo files update (#441)
  * test: test for config file creation and default config file parsing (#459)
  * feat: support Bob (#461)
  * chore: update bug report issue template (#474)
  * fix(pip3): prefer python when available (#471)
  * fix: Run AstroUpdate before Lazy sync (#473)
  * fix: handle no topgrade.toml but files in topgrade.d (#460)
  * refactor: unify the behavior of the steps that require sudo (#467)
  * fix: fix Mist (#466)
  * Revert "fix: fix mist" (#465)
  * fix: fix mist (#464)
  * refactor: make update fn take &ExectionContext & put update fn together (#457)
  * docs: update CONTRIBUTING.md & config.example.toml (#458)
  * fix: warn user about bad pattern paths before skipping step git (#456)
  * fix: Handle '# [include]'. Update default config (#450)
  * fix: run AM without sudo (#454)
  * docs: add config-related CONTRIBUTING doc (#452)
  * fix: Write to correct config path when none exists. (#449)
  * feat: Add arguments to pipupgrade and fix enable_pipupgrade check (#448)
  * feat: support Vanilla Linux (#447)
  * refactor: remove Anarchy and Antergos as they are discontinued (#446)
  * fix: fix panic during container update (#445)
  * feat: support deepin OS (#444)
  * refactor: remove unnecessary qualification (#443)
  * refactor: rename update fn name & some cleanup (#442)
  * Allow apt-get update to continue to apt-get upgrade with error code 100 (#440)
  * Merge code for desktop notification between MacOS and Linux (#438)
  * docs: CONTRIBUTING.md (#439)
  * Added ability to include directories as an extension of the config file (#421)
  * fix: fix .NET language issue (#437)
  * refactor: make all step functions take &ExectutionContext (#436)
  * fix: use --platform opt when pulling containers (#435)
  * fix: use env ZSH to compose oh-my-zsh install dir (#434)
  * fix: run deb-get without sudo (#430)
  * Adding local pip-review (#433)
  * Differentiate NPM and PNPM steps in name (#431)
  * feat: support maza (#427)
  * feat: support oh-my-bash (#425)
  * feat: support AppMan (#423)
  * feat(shell): add `packer.nu` (#414)
  * Make `zypper dist-upgrade` opt-in on SLE/Leap (#417)
  * feat: support stew (#422)
  * docs: update README for alternative config path (#419)
  * Add the ability to have the config file in $XDG_CONFIG_HOME/topgrade/topgrade.toml (#418)
* Fri May  5 2023 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Initial packaging of v11.0.2
  * Add Scoop manifest link for Windows installation
  * run_custom_command: allow using interactive shell on unix
  * Add no-self-update config and flag
  * Display the preamble in Linux only if notify-send is installed
  * No need to run self-update in Rustup
  * Bump h2 from 0.3.16 to 0.3.17
  * Added support to 'mamba' (alternative to 'conda' with the exact same commands/interface)
  * Bump enumflags2 from 0.7.5 to 0.7.7
  * Assume Fedora Silverblue based on os-release and not on existence of rpm-ostree
  * Replace directories with home & etcetera
  * dependency update
